% Transfer function of a comb filter, which acts as a basis for the flanger effect.
% An evenly spaced comb filter structure is obtained using a set of harmonic frequencies.
% The idea is to add together two signals which have a certain time delay between them.
clear all
clc

% time delay of the original set of harmonic sine waves
t0 = 0;

% fundamental frequency of the set of harmonic sine waves
f0 = 50;

% this parameter sets the ordinal number for the first harmonic
% that is wanted to be cancelled by the flanger comb filter
harmonic = 20;

% the ordinal number of the cancelled harmonic is used to
% determine the time needed to delay the original signal
% to create the desired comb filter effect
t1 = -1/(2*harmonic*f0)

% the angular frequency is calculated directly from the fundamental frequency
w0 = 2*pi*f0;

% number of harmonic sine waves included to the experimental setup
n = 1:200;

% create the analytic signal for the non-delayed signal
% a series of harmonic frequencies as if measured
% from a vibrating guitar string
y = (1./n.^2).*sin(n.*w0*t0);

% create the analytic signal for the delayed signal
% a series of harmonic frequencies as if measured
% from a vibrating guitar string
x = (1./n.^2).*sin(n.*w0*t1);

% calculate the sum of the original signal y and the delayed signal x
X = abs(y' + x');

% calculate the harmonic frequencies for plotting purposes
F = f0*n'; 

% plot the comb filter transfer characteristics
semilogy(F,X);

